@@ -86,7 +86,7 @@
 #define KCONFIGWIDGETS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KCONFIGWIDGETS_NO_DEPRECATED
-#  define KCONFIGWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55b00
+#  define KCONFIGWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56200
 #endif
 #ifdef KCONFIGWIDGETS_NO_DEPRECATED_WARNINGS
 #  define KCONFIGWIDGETS_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KCONFIGWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KCONFIGWIDGETS_DEPRECATED_WARNINGS_SINCE KCONFIGWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KCONFIGWIDGETS_DEPRECATED_WARNINGS_SINCE 0x55b00
+#    define KCONFIGWIDGETS_DEPRECATED_WARNINGS_SINCE 0x56200
 #  endif
 #endif
 
@@ -193,6 +193,12 @@
 #else
 #  define KCONFIGWIDGETS_DEPRECATED_VERSION_5_90(text)
 #endif
+
+#if KCONFIGWIDGETS_DEPRECATED_WARNINGS_SINCE >= 0x55d00
+#  define KCONFIGWIDGETS_DEPRECATED_VERSION_5_93(text) KCONFIGWIDGETS_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KCONFIGWIDGETS_DEPRECATED_VERSION_5_93(text)
+#endif
 #define KCONFIGWIDGETS_DEPRECATED_VERSION_4(minor, text)      KCONFIGWIDGETS_DEPRECATED_VERSION_4_##minor(text)
 #define KCONFIGWIDGETS_DEPRECATED_VERSION_5(minor, text)      KCONFIGWIDGETS_DEPRECATED_VERSION_5_##minor(text)
 #define KCONFIGWIDGETS_DEPRECATED_VERSION(major, minor, text) KCONFIGWIDGETS_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
@@ -204,6 +210,8 @@
 #  define KCONFIGWIDGETS_ENUMERATOR_DEPRECATED_VERSION(major, minor, text)
 #  define KCONFIGWIDGETS_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
 #endif
+#define KCONFIGWIDGETS_WITH_KAUTH 1
+
 
 #endif /* KCONFIGWIDGETS_EXPORT_H */
 
@@ -259,7 +267,7 @@
 #define KCONFIGWIDGETS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KCONFIGWIDGETS_NO_DEPRECATED
-#  define KCONFIGWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55b00
+#  define KCONFIGWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56200
 #endif
 #ifdef KCONFIGWIDGETS_NO_DEPRECATED_WARNINGS
 #  define KCONFIGWIDGETS_DEPRECATED_WARNINGS_SINCE 0
@@ -269,7 +277,7 @@
 #  ifdef KCONFIGWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KCONFIGWIDGETS_DEPRECATED_WARNINGS_SINCE KCONFIGWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KCONFIGWIDGETS_DEPRECATED_WARNINGS_SINCE 0x55b00
+#    define KCONFIGWIDGETS_DEPRECATED_WARNINGS_SINCE 0x56200
 #  endif
 #endif
 
@@ -366,6 +374,12 @@
 #else
 #  define KCONFIGWIDGETS_DEPRECATED_VERSION_5_90(text)
 #endif
+
+#if KCONFIGWIDGETS_DEPRECATED_WARNINGS_SINCE >= 0x55d00
+#  define KCONFIGWIDGETS_DEPRECATED_VERSION_5_93(text) KCONFIGWIDGETS_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KCONFIGWIDGETS_DEPRECATED_VERSION_5_93(text)
+#endif
 #define KCONFIGWIDGETS_DEPRECATED_VERSION_4(minor, text)      KCONFIGWIDGETS_DEPRECATED_VERSION_4_##minor(text)
 #define KCONFIGWIDGETS_DEPRECATED_VERSION_5(minor, text)      KCONFIGWIDGETS_DEPRECATED_VERSION_5_##minor(text)
 #define KCONFIGWIDGETS_DEPRECATED_VERSION(major, minor, text) KCONFIGWIDGETS_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
@@ -377,6 +391,8 @@
 #  define KCONFIGWIDGETS_ENUMERATOR_DEPRECATED_VERSION(major, minor, text)
 #  define KCONFIGWIDGETS_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
 #endif
+#define KCONFIGWIDGETS_WITH_KAUTH 1
+
 
 
 #endif /* ECM_GENERATEEXPORTHEADER_KCONFIGWIDGETS_EXPORT_H */
